From a3167cc8a22bc6f1f1516853d2f969f16243e856 Mon Sep 17 00:00:00 2001
From: Pierangelo Masarati <ando@openldap.org>
Date: Fri, 9 Jun 2006 23:13:08 +0000
Subject: [PATCH] cleanup

---
 tests/progs/slapd-bind.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/tests/progs/slapd-bind.c b/tests/progs/slapd-bind.c
index 7bc02baae6..7f4b601da7 100644
--- a/tests/progs/slapd-bind.c
+++ b/tests/progs/slapd-bind.c
@@ -394,13 +394,13 @@ novals:;
 #endif
 
 	if ( ndns == 0 ) {
-		tester_error( "No RDNs" );
+		tester_error( "No DNs" );
 		return 1;
 	}
 
 	fprintf( stderr, "  PID=%ld - got %d values.\n", (long) pid, ndns );
 
 	/* Ok, got list of RDNs, now start binding to each */
 	for ( i = 0; i < maxloop; i++ ) {
 		int j, k;
 		struct berval *cred = pass;
@@ -394,13 +394,13 @@ novals:;
 	fprintf( stderr, "  PID=%ld - got %d values.\n", (long) pid, ndns );
 
-	/* Ok, got list of RDNs, now start binding to each */
+	/* Ok, got list of DNs, now start binding to each */
 	for ( i = 0; i < maxloop; i++ ) {
 		int j, k;
-- 
GitLab